@@ -10,7 +10,6 @@ import click_completion
 
 import pendulum
 from prettytable import PrettyTable
-from notifypy import Notify
 
 from toggl import api, exceptions, utils, __version__
 from toggl.cli import helpers, types
@@ -142,6 +141,7 @@ def visit_www():
 @click.argument('start', type=types.DateTimeType(allow_now=True))
 @click.argument('stop', type=types.DateTimeDurationType())
 @click.argument('descr')
+@click.option('--billable', '-b', is_flag=True, help="Sets the Entry to be Billable")
 @click.option('--tags', '-a', type=types.SetType(), help='List of tags delimited with \',\'')
 @click.option('--project', '-o', envvar="TOGGL_PROJECT", type=types.ResourceType(api.Project),
               help='Link the entry with specific project. Can be ID or name of the project (ENV: TOGGL_PROJECT)', )
@@ -221,7 +221,7 @@ def entry_ls(ctx, fields, today, use_reports, **conditions):
     Lists time entries the user has access to.
 
     By default the command uses API call that has limited number of time entries fetched  with 1000 entries in
-    last 9 days. If you want to overcome this limitation use --user-reports flag, that will use different
+    last 9 days. If you want to overcome this limitation use --use-reports flag, that will use different
     API call, which overcomes this limitations but currently support only --start/--stop filtration.
 
     The list visible
@@ -289,11 +289,12 @@ def entry_ls(ctx, fields, today, use_reports, **conditions):
               help='Defines start of a date range to filter the entries by.')
 @click.option('--stop', '-p', type=types.DateTimeType(), help='Defines stop of a date range to filter the entries by.')
 @click.option('--today', '-t', is_flag=True, help='Scopes the time to the current day')
+@click.option('--show-total', '-st', is_flag=True, help='Shows total aggregation.')
 @click.option('--project', '-o', type=types.ResourceType(api.Project),
               help='Filters the entries by project. Can be ID or name of the project.', )
 @click.option('--tags', '-a', type=types.SetType(), help='Filters the entries by list of tags delimited with \',\'')
 @click.pass_context
-def entry_sum(ctx, use_reports, today, **conditions):
+def entry_sum(ctx, use_reports, today, show_total, **conditions):
     """
     Shows summary of totally tracked time based on days.
     Displayed Total time is in format HH:MM:SS
@@ -311,6 +312,10 @@ def entry_sum(ctx, use_reports, today, **conditions):
     entries = get_entries(ctx, use_reports, **conditions)
     sums_per_day = get_times_based_on_days(entries, config)
 
+    if show_total:
+        sums_per_day.insert(0, ["total",
+                                reduce((lambda x, y: x + y), [duration for _, duration in sums_per_day])])
+
     table = PrettyTable()
     table.field_names = [click.style('Day', **theme.header), click.style('Total time', **theme.header)]
     table.border = False
@@ -419,6 +424,7 @@ def entry_rm(ctx, spec):
 @click.argument('descr', required=False)
 @click.option('--start', '-s', type=types.DateTimeType(allow_now=True), help='Specifies start of the time entry. '
                                                                              'If left empty \'now\' is assumed.')
+@click.option('--billable', '-b', is_flag=True, help="Sets the Entry to be Billable")
 @click.option('--tags', '-a', type=types.SetType(), help='List of tags delimited with \',\'')
 @click.option('--project', '-o', envvar="TOGGL_PROJECT", type=types.ResourceType(api.Project),
               help='Link the entry with specific project. Can be ID or name of the project (ENV: TOGGL_PROJECT)', )
